@@ -2,12 +2,6 @@ import pytest
 from svvamp import Profile
 
 
-def test_not_enough_voters():
-    with pytest.raises(ValueError):
-        profile = Profile(preferences_ut=[[1, 0]])
-        _ = profile.n_v
-
-
 def test_not_enough_candidates():
     with pytest.raises(ValueError):
         profile = Profile(preferences_ut=[[1], [0]])
